==> easy-antd-modal-1.4.0.tgz: package/es/drag-modal/BaseModal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["modalRender", "title", "offsetX", "offsetY"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import { useDraggable } from '@dnd-kit/core';
import { CSS } from '@dnd-kit/utilities';
import Modal from "../modal";
import { jsx as _jsx } from "react/jsx-runtime";
function BaseModal(props) {
  var modalRender = props.modalRender,
    title = props.title,
    offsetX = props.offsetX,
    offsetY = props.offsetY,
    resetProps = _objectWithoutProperties(props, _excluded);
  var _useDraggable = useDraggable({
      id: 'easy-antd-modal-draggable-modal'
    }),
    attributes = _useDraggable.attributes,
    isDragging = _useDraggable.isDragging,
    listeners = _useDraggable.listeners,
    setNodeRef = _useDraggable.setNodeRef,
    transform = _useDraggable.transform;
  var mergeModalRender = function mergeModalRender(rawNode) {
    var _modalRender;
    return /*#__PURE__*/_jsx("div", {
      ref: setNodeRef,
      style: {
        position: 'relative',
        transform: isDragging ? CSS.Transform.toString(transform) : undefined,
        top: offsetY,
        left: offsetX
      },
      children: (_modalRender = modalRender === null || modalRender === void 0 ? void 0 : modalRender(rawNode)) !== null && _modalRender !== void 0 ? _modalRender : rawNode
    });
  };
  return /*#__PURE__*/_jsx(Modal, _objectSpread({
    title: /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread(_objectSpread({}, listeners), attributes), {}, {
      style: {
        cursor: 'move'
      },
      children: title
    })),
    modalRender: mergeModalRender
  }, resetProps));
}
export default BaseModal;

==> easy-antd-modal-1.4.1.tgz: package/es/drag-modal/BaseModal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["modalRender", "title", "offsetX", "offsetY", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import { useDraggable } from '@dnd-kit/core';
import { CSS } from '@dnd-kit/utilities';
import usePrefixCls from "../hooks/usePrefixCls";
import Modal from "../modal";
import { jsx as _jsx } from "react/jsx-runtime";
function BaseModal(props) {
  var modalRender = props.modalRender,
    title = props.title,
    offsetX = props.offsetX,
    offsetY = props.offsetY,
    className = props.className,
    resetProps = _objectWithoutProperties(props, _excluded);
  var prefixCls = usePrefixCls('drag-modal', props.prefixCls);
  var _useDraggable = useDraggable({
      id: 'easy-antd-modal-draggable-modal'
    }),
    attributes = _useDraggable.attributes,
    isDragging = _useDraggable.isDragging,
    listeners = _useDraggable.listeners,
    setNodeRef = _useDraggable.setNodeRef,
    transform = _useDraggable.transform;
  var mergeModalRender = function mergeModalRender(rawNode) {
    var _modalRender;
    return /*#__PURE__*/_jsx("div", {
      ref: setNodeRef,
      style: {
        position: 'relative',
        transform: isDragging ? CSS.Transform.toString(transform) : undefined,
        top: offsetY,
        left: offsetX
      },
      className: "".concat(prefixCls, "-content__wrapper"),
      children: (_modalRender = modalRender === null || modalRender === void 0 ? void 0 : modalRender(rawNode)) !== null && _modalRender !== void 0 ? _modalRender : rawNode
    });
  };

  // Compliance with BEM norms
  var modalCls = [className, isDragging && "".concat(prefixCls, "_dragging")].filter(Boolean).join(' ');
  return /*#__PURE__*/_jsx(Modal, _objectSpread(_objectSpread({}, resetProps), {}, {
    prefixCls: prefixCls,
    className: modalCls,
    title: /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread(_objectSpread({}, listeners), attributes), {}, {
      style: {
        cursor: 'move'
      },
      className: "".concat(prefixCls, "-title__inner"),
      children: title
    })),
    modalRender: mergeModalRender
  }));
}
export default BaseModal;
